# `pyqtorch`

An efficient, large-scale emulator designed for quantum machine learning, seamlessly integrated with a PyTorch backend.

Please refer to our [Read the Docs](https://pyqtorch.readthedocs.io/en/latest/) for setup and usage info, along with the full documentation.
